@@ -1,11 +1,8 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 1069 2009-03-20 17:23:09Z mac $
+# $Id: interfaces.py 1184 2009-05-12 18:39:39Z mac $
 
-import z3c.form.interfaces
-import z3c.formui.interfaces
-import z3c.layer.pagelet
 import z3c.menu.ready2go
 
 
