@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: person.py 1081 2009-03-28 20:03:50Z mac $
+# $Id: person.py 1184 2009-05-12 18:39:39Z mac $
 
 from icemac.addressbook.address import interface_title_prefix_class_mapping
 from icemac.addressbook.i18n import MessageFactory as _
@@ -18,6 +18,7 @@ import zc.sourcefactory.contextual
 import zope.component
 import zope.traversing.browser.interfaces
 
+
 def prefix_to_class(prefix):
     mapping = dict((x[2], x[3]) for x in interface_title_prefix_class_mapping)
     return mapping[prefix]
@@ -46,6 +47,15 @@ class EditGroup(AddGroup):
     def getContent(self):
         return self.context[self.key]
 
+
+class FileEditGroup(EditGroup):
+    """EditGroup for icemac.addressbook.file.interfaces.IFile objects."""
+
+    @property
+    def fields(self):
+        return super(FileEditGroup, self).fields
+
+
 class DefaultSelectGroup(icemac.addressbook.browser.base.PrefixGroup):
     """Group to select the default addresses."""
 
@@ -117,20 +127,35 @@ class PersonEditForm(
                     prefix, index, obj.__name__)
                 groups.append(group)
                 index += 1
+
+        iface = icemac.addressbook.file.interfaces.IFile
+        for obj in icemac.addressbook.utils.iter_by_interface(
+                self.context, iface):
+            group = FileEditGroup(
+                self.context, self.request, self, iface, _(u'file'), 'file',
+                index, obj.__name__)
+            groups.append(group)
+            index += 1
+
         self.groups = tuple(groups)
 
     @z3c.form.button.buttonAndHandler(_('Apply'), name='apply')
     def handleApply(self, action):
-        # because we define a new action we have to duplicate the
-        # existing action because otherwise we'll loose it.
         super(PersonEditForm, self).handleApply(self, action)
+        # update file's mime type after new file was uploaded
+        for group in self.groups:
+            if not isinstance(group, FileEditGroup):
+                continue
+            prefix = z3c.form.util.expandPrefix(group.prefix)
+            icemac.addressbook.browser.file.file.update_blob(
+                group.widgets[prefix+'data'], group.getContent())
 
     @z3c.form.button.buttonAndHandler(_('Cancel'), name='cancel')
     def handleCancel(self, action):
         self.status = self.noChangesMessage
 
     @z3c.form.button.buttonAndHandler(
-        _(u'Delete person'), name='delete_person',
+        _(u'Delete whole person'), name='delete_person',
         condition=icemac.addressbook.browser.base.all_(
             icemac.addressbook.browser.base.can_access('@@delete_person.html'),
             person_deletable))
@@ -141,14 +166,14 @@ class PersonEditForm(
         self.request.response.redirect(url + '/@@delete_person.html')
 
     @z3c.form.button.buttonAndHandler(
-        _(u'Delete address or number'), name='delete_address',
+        _(u'Delete single entry'), name='delete_entry',
         condition=icemac.addressbook.browser.base.can_access(
-            '@@delete_address.html'))
+            '@@delete_entry.html'))
     def handleDeleteAddress(self, action):
         url = zope.component.getMultiAdapter(
             (self.context, self.request),
             zope.traversing.browser.interfaces.IAbsoluteURL)()
-        self.request.response.redirect(url + '/@@delete_address.html')
+        self.request.response.redirect(url + '/@@delete_entry.html')
 
 
 class KeywordDataManager(z3c.form.datamanager.AttributeField):
@@ -185,9 +210,17 @@ class PersonEntriesSource(
             for value in icemac.addressbook.sources.ContextByInterfaceSource(
                 interface).factory.getValues(context):
                 yield value
+        for value in icemac.addressbook.sources.ContextByInterfaceSource(
+            icemac.addressbook.file.interfaces.IFile).factory.getValues(
+            context):
+            yield value
 
     def getTitle(self, context, value):
-        title_prefix = icemac.addressbook.address.object_to_title(value)
+        try:
+            title_prefix = icemac.addressbook.address.object_to_title(value)
+        except KeyError:
+            # up to now there are only files besides the address entries
+            title_prefix = _('file')
         title = icemac.addressbook.interfaces.ITitle(value)
         if title_prefix:
             title = '%s -- %s' % (title_prefix, title)
@@ -201,7 +234,7 @@ class IPersonEntries(zope.interface.Interface):
         title=_(u'Entries'), source=PersonEntriesSource())
 
 
-class DeleteAddressForm(icemac.addressbook.browser.base.BaseEditForm):
+class DeleteSingleEntryForm(icemac.addressbook.browser.base.BaseEditForm):
 
     label = _(u'Please choose an entry for deletion:')
     interface = IPersonEntries
