@@ -1,21 +1,13 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: table.py 1047 2009-03-14 09:35:01Z mac $
-
-import z3c.form.button
-import z3c.table.column
-import z3c.table.table
-import zc.sourcefactory.interfaces
-import zope.interface
-import zope.schema
-import zope.session.interfaces
-import icemac.truncatetext
-
-import icemac.addressbook.browser.base
-import icemac.addressbook.interfaces
+# $Id: table.py 1184 2009-05-12 18:39:39Z mac $
 
 from icemac.addressbook.i18n import MessageFactory as _
+import icemac.addressbook.interfaces
+import icemac.truncatetext
+import z3c.table.column
+import z3c.table.table
 
 
 # Columns
