@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 935 2009-01-08 10:19:09Z mac $
+# $Id: tests.py 1124 2009-04-07 18:42:58Z mac $
 
 import unittest
 import zope.interface.verify
@@ -26,7 +26,4 @@ class TestInterfaces(unittest.TestCase):
 
 
 def test_suite():
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(TestInterfaces))
-    suite.layer = icemac.addressbook.testing.AddressBookUnitTests
-    return suite
+    return icemac.addressbook.testing.UnittestSuite(TestInterfaces)
