@@ -1,12 +1,11 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: evolve1.py 913 2009-01-02 12:47:38Z mac $
+# $Id: evolve1.py 1121 2009-04-05 20:19:30Z mac $
 
 __docformat__ = "reStructuredText"
 
 import zope.app.generations.utility
-import zope.app.zopeappgenerations
 
 import icemac.addressbook.interfaces
 import icemac.addressbook.addressbook
@@ -20,11 +19,11 @@ person_created_with_set_site = icemac.addressbook.utils.set_site(
 
 def evolve(context):
     """Installs the necessary components for address books.
-    
+
     Defines references on persons.
     """
 
-    root = zope.app.zopeappgenerations.getRootFolder(context)
+    root = zope.app.generations.utility.getRootFolder(context)
     # persons need gocept.reference which needs a local utility stored in root
 
     # persons
