@@ -1,12 +1,11 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: evolve2.py 1001 2009-02-07 08:10:56Z mac $
+# $Id: evolve2.py 1121 2009-04-05 20:19:30Z mac $
 
 __docformat__ = "reStructuredText"
 
 import zope.app.generations.utility
-import zope.app.zopeappgenerations
 import zope.catalog.interfaces
 
 import icemac.addressbook.interfaces
@@ -29,7 +28,7 @@ def evolve(context):
 
     """
 
-    root = zope.app.zopeappgenerations.getRootFolder(context)
+    root = zope.app.generations.utility.getRootFolder(context)
 
     # fix steet attribute
     addresses = zope.app.generations.utility.findObjectsProviding(
