@@ -1,12 +1,11 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: evolve3.py 1096 2009-03-31 19:28:59Z mac $
+# $Id: evolve3.py 1121 2009-04-05 20:19:30Z mac $
 
 __docformat__ = "reStructuredText"
 
 import zope.app.generations.utility
-import zope.app.zopeappgenerations
 
 import icemac.addressbook.interfaces
 import icemac.addressbook.addressbook
@@ -24,7 +23,7 @@ def evolve(context):
     """Installs the authentication utility.
     """
 
-    root = zope.app.zopeappgenerations.getRootFolder(context)
+    root = zope.app.generations.utility.getRootFolder(context)
     # persons need gocept.reference which needs a local utility stored in root
 
     # addressbooks
