@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: interfaces.py 913 2009-01-02 12:47:38Z mac $
+# $Id: interfaces.py 938 2009-01-08 10:20:58Z mac $
 
 import gocept.country
 import gocept.country.db
@@ -36,6 +36,8 @@ class IAddressBook(zope.interface.Interface):
     """An address book."""
 
     keywords = zope.interface.Attribute(u'keywords collection (IKeywords).')
+    principals = zope.interface.Attribute(
+        u'zope.app.authentication.interfaces.IInternalPrincipalContainer')
 
     title = zope.schema.TextLine(title=_(u'title'))
     notes = zope.schema.Text(title=_(u'notes'), required=False)
@@ -53,7 +55,7 @@ class IPerson(zope.interface.Interface):
     keywords = zope.schema.Set(
         title=_('keywords'), required=False,
         value_type=zope.schema.Choice(
-            title=_('keywords'), 
+            title=_('keywords'),
             source=icemac.addressbook.sources.keyword_source))
     notes = zope.schema.Text(title=_(u'notes'), required=False)
 
@@ -74,7 +76,7 @@ class IPostalAddress(zope.interface.Interface):
         title=_(u'country'), source=gocept.country.countries,
         required=False, default=gocept.country.db.Country('DE'))
     state = zope.schema.Choice(
-        title=_(u'state'), required=False, 
+        title=_(u'state'), required=False,
         source=gocept.country.SubdivisionSource(country_code=['DE']))
     notes = zope.schema.Text(title=_(u'notes'), required=False)
 
@@ -125,7 +127,7 @@ class IPersonDefaults(zope.interface.Interface):
     """Default addresses, phone numbers etc."""
 
     default_postal_address = zope.schema.Choice(
-        title=_(u'main postal address'), 
+        title=_(u'main postal address'),
         source=icemac.addressbook.sources.ContextByInterfaceSource(
             IPostalAddress))
     default_phone_number = zope.schema.Choice(
@@ -133,11 +135,11 @@ class IPersonDefaults(zope.interface.Interface):
         source=icemac.addressbook.sources.ContextByInterfaceSource(
             IPhoneNumber))
     default_email_address = zope.schema.Choice(
-        title=_(u'main e-mail address'), 
+        title=_(u'main e-mail address'),
         source=icemac.addressbook.sources.ContextByInterfaceSource(
             IEMailAddress))
     default_home_page_address = zope.schema.Choice(
-        title=_(u'main home page address'), 
+        title=_(u'main home page address'),
         source=icemac.addressbook.sources.ContextByInterfaceSource(
             IHomePageAddress))
 
