@@ -1,12 +1,12 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: keyword.py 913 2009-01-02 12:47:38Z mac $
+# $Id: keyword.py 1001 2009-02-07 08:10:56Z mac $
 
 import persistent
-import zope.app.catalog.interfaces
-import zope.app.container.btree
-import zope.app.container.contained
+import zope.catalog.interfaces
+import zope.container.btree
+import zope.container.contained
 import zope.component
 import zope.interface
 import zope.lifecycleevent
@@ -17,10 +17,10 @@ import icemac.addressbook.interfaces
 from icemac.addressbook.i18n import MessageFactory as _
 
 
-class KeywordContainer(zope.app.container.btree.BTreeContainer):
+class KeywordContainer(zope.container.btree.BTreeContainer):
     "A container for keywords."
     zope.interface.implements(icemac.addressbook.interfaces.IKeywords)
-    
+
     def get_keywords(self):
         return sorted(self.values(), key=lambda x: x.title)
 
@@ -28,7 +28,7 @@ class KeywordContainer(zope.app.container.btree.BTreeContainer):
         return [x.title for x in self.get_keywords()]
 
 
-class Keyword(persistent.Persistent, zope.app.container.contained.Contained):
+class Keyword(persistent.Persistent, zope.container.contained.Contained):
     "A keyword."
     zope.interface.implements(icemac.addressbook.interfaces.IKeyword)
 
@@ -46,7 +46,7 @@ def changed(obj, event):
         if (desc.interface == icemac.addressbook.interfaces.IKeyword and
             'title' in desc.attributes):
             catalog = zope.component.getUtility(
-                zope.app.catalog.interfaces.ICatalog)
+                zope.catalog.interfaces.ICatalog)
             catalog.updateIndex(catalog.get('keywords'))
             break
 
