@@ -1,11 +1,11 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: person.py 918 2009-01-02 19:35:06Z mac $
+# $Id: person.py 997 2009-02-03 16:58:46Z mac $
 
 import gocept.reference
 import zope.annotation.interfaces
-import zope.app.container.btree
+import zope.container.btree
 import zope.interface
 import zope.lifecycleevent
 import zope.schema.fieldproperty
@@ -13,7 +13,7 @@ import zope.schema.fieldproperty
 import icemac.addressbook.interfaces
 import icemac.addressbook.sources
 
-class Person(zope.app.container.btree.BTreeContainer):
+class Person(zope.container.btree.BTreeContainer):
     "A person."
 
     zope.interface.implements(icemac.addressbook.interfaces.IPerson,
