@@ -1,15 +1,14 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: tests.py 1080 2009-03-26 17:41:06Z mac $
+# $Id: tests.py 1124 2009-04-07 18:42:58Z mac $
 
 import gocept.reference.verify
-import unittest
-import zope.interface.verify
-
-import icemac.addressbook.testing
 import icemac.addressbook.principals.interfaces
 import icemac.addressbook.principals.principals
+import icemac.addressbook.testing
+import unittest
+import zope.interface.verify
 
 
 class TestInterfaces(unittest.TestCase):
@@ -29,7 +28,5 @@ class TestInterfaces(unittest.TestCase):
 
 
 def test_suite():
-    suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(TestInterfaces))
-    suite.layer = icemac.addressbook.testing.AddressBookUnitTests
-    return suite
+    return icemac.addressbook.testing.UnittestSuite(TestInterfaces)
+
