@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Copyright (c) 2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: testing.py 1084 2009-03-29 13:53:11Z mac $
+# $Id: testing.py 1161 2009-05-01 12:27:31Z mac $
 
 import doctest
 import icemac.addressbook.address
@@ -11,14 +11,16 @@ import icemac.addressbook.person
 import icemac.addressbook.principals.principals
 import icemac.addressbook.principals.sources
 import icemac.addressbook.utils
+import os
 import os.path
+import tempfile
+import unittest
 import zope.annotation.attribute
 import zope.app.testing.functional
-import zope.testing.cleanup
-import zope.testing.testrunner.layer
 import zope.testbrowser.browser
 import zope.testbrowser.interfaces
-
+import zope.testing.cleanup
+import zope.testing.testrunner.layer
 
 class AddressBookUnitTests(zope.testing.testrunner.layer.UnitTests):
     """Layer for gathering addressbook unit tests."""
@@ -35,17 +37,23 @@ class AddressBookUnitTests(zope.testing.testrunner.layer.UnitTests):
         zope.testing.cleanup.tearDown()
 
 
+def UnittestSuite(class_):
+    """Create a unittest test suite from a unittest test class."""
+    suite = unittest.makeSuite(class_)
+    suite.layer = AddressBookUnitTests
+    return suite
+
+
 # XXX zope.app.testing.functional.defineLayer benutzen
 ftesting_zcml = os.path.join(os.path.dirname(__file__), 'ftesting.zcml')
 FunctionalLayer = zope.app.testing.functional.ZCMLLayer(
     ftesting_zcml, __name__, 'FunctionalLayer')
 
 
-# def FunctionalDocTestSuite(module=None, **kw):
-#     module = zope.testing.doctest._normalize_module(module)
-#     suite = zope.app.testing.functional.FunctionalDocTestSuite(module, **kw)
-#     suite.layer = FunctionalLayer
-#     return suite
+class FunctionalTestCase(zope.app.testing.functional.FunctionalTestCase):
+    """Base class for functional tests."""
+
+    layer = FunctionalLayer
 
 
 def FunctionalDocFileSuite(*paths, **kw):
@@ -57,10 +65,6 @@ def FunctionalDocFileSuite(*paths, **kw):
     return suite
 
 
-class FunctionalTestCase(zope.app.testing.functional.FunctionalTestCase):
-    layer = FunctionalLayer
-
-
 def _get_control_names(interface, browser=None, form=None):
     """Get a sorted list of names of controls providing the given interface.
 
@@ -77,6 +81,7 @@ def _get_control_names(interface, browser=None, form=None):
             names.append(control.name)
     return sorted(names)
 
+
 def get_submit_control_names(browser=None, form=None):
     """Get a list of the names of the submit controls in the form.
 
@@ -95,6 +100,14 @@ def get_all_control_names(browser=None, form=None):
         zope.testbrowser.interfaces.IControl, browser, form)
 
 
+def write_temp_file(content, suffix):
+    "Write `content` to a temporary file and return file handle and file name."
+    fd, filename = tempfile.mkstemp(suffix=suffix)
+    os.write(fd, content)
+    os.close(fd)
+    return file(filename, 'r'), filename
+
+
 def create_addressbook(parent=None, name='ab', title=u'test address book'):
     ab = icemac.addressbook.utils.create_obj(
         icemac.addressbook.addressbook.AddressBook, title=title)
@@ -164,6 +177,7 @@ def create_phone_number(person, set_as_default=True, return_obj=True, **kw):
     if return_obj:
         return number
 
+
 @icemac.addressbook.utils.set_site
 def create_user(ab, first_name, last_name, email, password, roles):
     person = create_person(
