@@ -1,22 +1,23 @@
 # -*- coding: latin-1 -*-
 # Copyright (c) 2008-2009 Michael Howitz
 # See also LICENSE.txt
-# $Id: utils.py 913 2009-01-02 12:47:38Z mac $
+# $Id: utils.py 997 2009-02-03 16:58:46Z mac $
 
-import zope.app.container.interfaces
+import zope.container.interfaces
 import zope.event
 import zope.lifecycleevent
+import zope.site.hooks
 
 
 def set_site(func):
     "Decorator which does the set-site-dance."
     def decorated(site, *args, **kw):
-        old_site = zope.app.component.hooks.getSite()
+        old_site = zope.site.hooks.getSite()
         try:
-            zope.app.component.hooks.setSite(site)
+            zope.site.hooks.setSite(site)
             return func(*args, **kw)
         finally:
-            zope.app.component.hooks.setSite(old_site)
+            zope.site.hooks.setSite(old_site)
     return decorated
 
 
@@ -33,7 +34,7 @@ create_obj_with_set_site = set_site(create_obj)
 
 
 def add(parent, obj):
-    nc = zope.app.container.interfaces.INameChooser(parent)
+    nc = zope.container.interfaces.INameChooser(parent)
     name = nc.chooseName('', obj)
     parent[name] = obj
     return name
