@@ -13,7 +13,7 @@
 ##############################################################################
 """Widget Framework Implementation
 
-$Id: datamanager.py 90332 2008-08-26 14:11:43Z hermann $
+$Id: datamanager.py 96365 2009-02-10 03:48:08Z nadako $
 """
 __docformat__ = "reStructuredText"
 
@@ -47,7 +47,7 @@ class AttributeField(DataManager):
             context = self.field.interface(context)
         return getattr(context, self.field.__name__)
 
-    def query(self, default=interfaces.NOVALUE):
+    def query(self, default=interfaces.NO_VALUE):
         """See z3c.form.interfaces.IDataManager"""
         try:
             return self.get()
@@ -103,7 +103,7 @@ class DictionaryField(DataManager):
         """See z3c.form.interfaces.IDataManager"""
         return self.data[self.field.__name__]
 
-    def query(self, default=interfaces.NOVALUE):
+    def query(self, default=interfaces.NO_VALUE):
         """See z3c.form.interfaces.IDataManager"""
         return self.data.get(self.field.__name__, default)
 
