@@ -13,14 +13,14 @@
 ##############################################################################
 """Error Views Implementation
 
-$Id: error.py 93230 2008-11-21 09:14:51Z adamg $
+$Id: error.py 97381 2009-02-28 12:26:20Z nadako $
 """
 __docformat__ = "reStructuredText"
 import os
 import zope.component
 import zope.interface
 import zope.schema
-from z3c.pt.compat import ViewPageTemplateFile
+from z3c import ptcompat
 from zope.pagetemplate.interfaces import IPageTemplate
 
 import z3c.form
@@ -114,8 +114,8 @@ class MultipleErrorViewSnippet(ErrorViewSnippet):
 
 
 class MultipleErrors(Exception):
-    zope.interface.implements(interfaces.IMultipleErrors)
     """An error that contains many errors"""
+    zope.interface.implements(interfaces.IMultipleErrors)
 
     def __init__(self, errors):
         self.errors = errors
@@ -127,7 +127,7 @@ class ErrorViewTemplateFactory(object):
     template = None
 
     def __init__(self, filename, contentType='text/html'):
-        self.template = ViewPageTemplateFile(filename, content_type=contentType)
+        self.template = ptcompat.ViewPageTemplateFile(filename, content_type=contentType)
 
     def __call__(self, errorView, request):
         return self.template
