@@ -13,7 +13,7 @@
 ##############################################################################
 """ObjectWidget related classes
 
-$Id: object.py 96469 2009-02-12 12:38:30Z nadako $
+$Id: object.py 98881 2009-04-05 16:46:19Z adamg $
 """
 __docformat__ = "reStructuredText"
 import zope.interface
@@ -146,6 +146,10 @@ class ObjectConverter(BaseDataConverter):
                 except AttributeError:
                     obj = self.createObject(value)
 
+        if obj is None or obj == self.field.missing_value:
+            #if still None create one, otherwise following will burp
+            obj = self.createObject(value)
+
         obj = self.field.schema(obj)
 
         names = []
@@ -265,7 +269,8 @@ class ObjectWidget(widget.Widget):
 
             if errors:
                 #very-very-nasty: skip raising exceptions in extract
-                #while we're updating
+                #while we're updating -- that happens when the widget
+                #is updated and update calls extract()
                 if self._updating:
                     return default
 
