@@ -13,7 +13,7 @@
 ##############################################################################
 """z3c.form Test Module
 
-$Id: test_doc.py 93794 2008-12-08 17:25:23Z adamg $
+$Id: test_doc.py 97381 2009-02-28 12:26:20Z nadako $
 """
 __docformat__ = "reStructuredText"
 import unittest
@@ -26,7 +26,7 @@ from zope.app.testing import placelesssetup
 from z3c.form import testing
 
 def test_suite():
-    checker = testing.OutputChecker()
+    checker = testing.OutputChecker(doctest)
 
     tests = ((
         doctest.DocFileSuite(
@@ -103,6 +103,9 @@ def test_suite():
                  (re.compile(
                   r"(invalid literal for int\(\)) with base 10: '(.*)'"),
                   r'\1: \2'),
+                 (re.compile(
+                  r"Decimal\('(.*)'\)"),
+                  r'Decimal("\1")'),
                  ])
             ),
         doctest.DocFileSuite(
@@ -141,7 +144,6 @@ def test_suite():
             optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
             checker=checker,
             ))
-        #for setUp in (testing.setUpZPT, testing.setUpZ3CPT))
-        for setUp in (testing.setUpZPT, ))
+        for setUp in (testing.setUpZPT, testing.setUpZ3CPT))
 
     return unittest.TestSuite(itertools.chain(*tests))
