@@ -13,7 +13,7 @@
 ##############################################################################
 """Widget Framework Implementation
 
-$Id: widget.py 96365 2009-02-10 03:48:08Z nadako $
+$Id: widget.py 98880 2009-04-05 16:03:37Z adamg $
 """
 __docformat__ = "reStructuredText"
 
@@ -249,6 +249,8 @@ class MultiWidget(Widget):
     widgets = None
     _value = None
 
+    _mode = FieldProperty(interfaces.IWidget['mode'])
+
     def __init__(self, request):
         super(MultiWidget, self).__init__(request)
         self.widgets = []
@@ -265,6 +267,18 @@ class MultiWidget(Widget):
         return '<input type="hidden" name="%s" value="%d" />' % (
             self.counterName, len(self.widgets))
 
+    @apply
+    def mode():
+        """This invokes updateWidgets on any value change e.g. update/extract."""
+        def get(self):
+            return self._mode
+        def set(self, mode):
+            self._mode = mode
+            # ensure that we apply the new mode to the widgets
+            for w in self.widgets:
+                w.mode = mode
+        return property(get, set)
+
     def getWidget(self, idx):
         """Setup widget based on index id with or without value."""
         valueType = self.field.value_type
